samuika: State-Space Assessment model Used for surume-IKA (samuika) –

Description Usage Arguments

View source: R/samuika.R

Description

State-Space Assessment model Used for surume-IKA (samuika) —-

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
samuika(
  catch_data,
  weight_data,
  index_data,
  SR = "BH",
  regime_year = NULL,
  regime_par = c("a", "b", "sd")[c(1, 2, 3)],
  regime_key = 0:length(regime_year),
  stock_shared_par = c("a", "b", "sd", "SDlogF", "SDlogC")[c(1:5)],
  SDlogCPUE_key = rep(0, length(unique(index_data$Index_ID))),
  beta_key = rep(0, length(unique(index_data$Index_ID))),
  beta_fix = 1,
  logZ_mean = NULL,
  logZ_sd = NULL,
  logZ_weight = NULL,
  restrict_mean = FALSE,
  add_cpue = NULL,
  add_cpue_info = NULL,
  add_cpue_tday = NULL,
  fish_days = 180,
  add_cpue_covariate = NULL,
  add_cpue_SDkey = NULL,
  add_cpue_error_type = 0,
  add_cpue_all = 1,
  Fprocess_remove_year = NULL,
  p0_list = NULL,
  M = 0.6,
  Pope = FALSE,
  scale_num_to_mass = 0.1,
  bias_correct = TRUE,
  bias_correct_control = list(sd = FALSE),
  fixed_par = c("a", "b", "sd", "rec_rho", "SDlogF", "rho_SDlogF", "SDlogC", "q",
    "SDlogCPUE")[6],
  map_add = NULL,
  logF_diff = 0,
  SDlogF_init = 0.2,
  rho_SDlogF_init = 0,
  reca_init = c(3.5),
  recb_init = ifelse(SR == "HS", 14, 0.04),
  recSD_init = 0.4,
  rec_rho_init = 0,
  SDlogC_init = 0.2,
  q_init = c(0.22, 0.5),
  SDcpue_init = 0.2,
  N_init = 23.7,
  F_init = 0.38,
  silent = FALSE,
  maxrep = 100,
  HS_restrict = TRUE,
  nlminb_control = list(eval.max = 2000, iter.max = 2000)
)

Arguments

catch_data

time-series of catch

weight_data

time-series of weight

index_data

time-series of indices

SR

stock-recruit function ("BH", "RI", or "HS")

regime_year

years when a regime shift occurred

regime_par

parameters that changed by the regime shift (c("a","b","sd"))

regime_key

KEY representing regime (e.g., c(0,1,0) indicates the first and the third regimes were identical)

stock_shared_par

parameter(s) that were shared between stocks (c("a","b","sd","SDlogF","SDlogC"))

logZ_mean

prior mean of logF (NOTICE: Not logZ!!)

logZ_sd

prior SD of logF (NOTICE: Not logZ!!)

logZ_weight

matrix for which years are included when using prior of logZ_mean and logZ_sd or add_cpue

add_cpue

VECTOR of additional cpue time-series

add_cpue_info

column 1: CPUE_ID, 2: Stock_ID, 3: Year_ID

add_cpue_tday

VECTOR of days since the beginning of fishing season

fish_days

duration of fishing season when using add_cpue (default: 180)

add_cpue_covariate

array used as covariate(s) for additional CPUE

add_cpue_error_type

error distribution for fitting additional CPUE; 0: lonormal, 1:log-Laplace, 2: gamma, 3: normal, 4: Laplace

add_cpue_all

fitting additional CPUE not separately per-year (0: FALSE, 1 (default): using mean(F+Z), 2: using mean(log(F+Z))

M

natural mortality coefficient (default: 0.6)

Pope

whether the Pope approximation is used (TRUE) or not (FALSE: default)

scale_num_to_mass

scaling multiplier in conversion of number to mass

bias_correct

bias correct option in sdreport

fixed_par

which parameters among c("a","b","sd","rec_rho","SDlogF","rho_SDlogF","SDlogC","q","SDlogCPUE") are fixed at their initial values

map_add

added factor to map other than fixed_par


ShotaNishijima/messir documentation built on April 2, 2020, 2:58 a.m.